==> haskell-multimap-1.2.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-multimap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 multimap
version:              1.2.1
visibility:           public
id:                   multimap-1.2.1-9JxmWLNMcxQ1AJJqmV9wuZ
key:                  multimap-1.2.1-9JxmWLNMcxQ1AJJqmV9wuZ
license:              MIT
maintainer:           Julian Fleischer <julian.fleischer@fu-berlin.de>
author:               Julian Fleischer <julian.fleischer@fu-berlin.de>
stability:            provisional
homepage:             http://hub.darcs.net/scravy/multimap
synopsis:             A multimap.
description:
    This is a simple implementation of a multimap, based on "Data.Map".

    [@v1.1@]
    @!@ had its arguments flipped. Fixed.
    Also added @fromMap@.

    [@v1.2@]
    Added "Data.SetMap", renamed @Multimap@ to "Data.MultiMap".
    Fixed the type of @delete@. Derive instances for @Data@
    and @Typeable@.

    [@v1.2.1@]
    Fixed typos in the documentation.

category:             Data Structures
abi:                  1415686e7d17a6e3bec3163cb79bbd4a
exposed:              True
exposed-modules:      Data.MultiMap Data.SetMap
import-dirs:          /usr/lib/ghc-9.0.2/site-local/multimap-1.2.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/multimap-1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-multimap
hs-libraries:         HSmultimap-1.2.1-9JxmWLNMcxQ1AJJqmV9wuZ
depends:              base-4.15.1.0 containers-0.6.4.1
haddock-interfaces:   /usr/share/doc/haskell-multimap/html/multimap.haddock
haddock-html:         /usr/share/doc/haskell-multimap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-multimap-1.2.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-multimap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 multimap
version:              1.2.1
visibility:           public
id:                   multimap-1.2.1-2IAvtGljS5zEVxuDX8lIuU
key:                  multimap-1.2.1-2IAvtGljS5zEVxuDX8lIuU
license:              MIT
maintainer:           Julian Fleischer <julian.fleischer@fu-berlin.de>
author:               Julian Fleischer <julian.fleischer@fu-berlin.de>
stability:            provisional
homepage:             http://hub.darcs.net/scravy/multimap
synopsis:             A multimap.
description:
    This is a simple implementation of a multimap, based on "Data.Map".

    [@v1.1@]
    @!@ had its arguments flipped. Fixed.
    Also added @fromMap@.

    [@v1.2@]
    Added "Data.SetMap", renamed @Multimap@ to "Data.MultiMap".
    Fixed the type of @delete@. Derive instances for @Data@
    and @Typeable@.

    [@v1.2.1@]
    Fixed typos in the documentation.

category:             Data Structures
abi:                  11b69bda8c8a6e9bdb09e09ef207ed10
exposed:              True
exposed-modules:      Data.MultiMap Data.SetMap
import-dirs:          /usr/lib/ghc-9.2.8/site-local/multimap-1.2.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/multimap-1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-multimap
hs-libraries:         HSmultimap-1.2.1-2IAvtGljS5zEVxuDX8lIuU
depends:              base-4.16.4.0 containers-0.6.5.1
haddock-interfaces:   /usr/share/doc/haskell-multimap/html/multimap.haddock
haddock-html:         /usr/share/doc/haskell-multimap/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
